@@ -1,7 +1,7 @@
 package Statistics::R::IO::Base;
 # ABSTRACT: Common object methods for processing R files
-$Statistics::R::IO::Base::VERSION = '0.09';
-use 5.012;
+$Statistics::R::IO::Base::VERSION = '0.091';
+use 5.010;
 
 use IO::File;
 use IO::Handle;
@@ -56,13 +56,13 @@ sub _read_and_uncompress {
     croak $! unless defined $rc;
     if (substr($data, 0, 2) eq "\x1f\x8b") {
         ## gzip-compressed file
-        $self->fh->seek(0, 0);
-        IO::Uncompress::Gunzip::gunzip $self->fh, \$data;
+        my $input = $data;
+        IO::Uncompress::Gunzip::gunzip \$input, \$data;
     }
     elsif (substr($data, 0, 3) eq 'BZh') {
         ## bzip2-compressed file
-        $self->fh->seek(0, 0);
-        IO::Uncompress::Bunzip2::bunzip2 $self->fh, \$data;
+        my $input = $data;
+        IO::Uncompress::Bunzip2::bunzip2 \$input, \$data;
     }
     elsif (substr($data, 0, 6) eq "\xfd7zXZ\0") {
         croak "xz-compressed R files are not supported";
@@ -106,7 +106,7 @@ Statistics::R::IO::Base - Common object methods for processing R files
 
 =head1 VERSION
 
-version 0.09
+version 0.091
 
 =head1 SYNOPSIS
 
